# extraneous

Find extraneous pip packages not listed in your requirements.txt or as a sub-dependency.

| Branch | Build Status | Coverage Status |
| ------ | ------------ | --------------- |
| master | [![Build Status](https://semaphoreci.com/api/v1/arrai-innovations/extraneous/branches/master/shields_badge.svg)](https://semaphoreci.com/arrai-innovations/extraneous) | [![Coverage Status](https://docs.arrai-dev.com/extraneous/htmlcov_master/coverage.svg)](https://docs.arrai-dev.com/extraneous/htmlcov_master/) |
| develop | [![Build Status](https://semaphoreci.com/api/v1/arrai-innovations/extraneous/branches/develop/shields_badge.svg)](https://semaphoreci.com/arrai-innovations/extraneous) | [![Coverage Status](https://docs.arrai-dev.com/extraneous/htmlcov_develop/coverage.svg)](https://docs.arrai-dev.com/extraneous/htmlcov_develop/) |
